==> hyades.source_1.0.3_20030929_1406.zip: org/eclipse/hyades/loaders/trace/TraceConstants.java <==
/**********************************************************************
 * Copyright (c) 2003 Hyades project.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v0.5
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v05.html
 *
 * Contributors:
 * IBM - Initial API and implementation
 **********************************************************************/
package org.eclipse.hyades.loaders.trace;

/**
 * @author slavescu
 */
public class TraceConstants {

	protected static final int ACCESS_int = -1423461020;
	protected static final int AGENT_ID_REF_int = -1203355277;
	protected static final int BASE_TIME_int = -1720547042;
	protected static final int CLASS_CLASS1_int = 1995981828;
	protected static final int CLASS_CLASS2_int = -530663260;
	protected static final int CLASS_ID_int = 853619891;
	protected static final int CLASS_ID_REF_int = -311104800;
	protected static final int CallStackPerThread_int = 688917711;
	protected static final int FIELD_ID_REF_int = 556029086;
	protected static final int ForwardInvocations_int = 1711643856;
	protected static final int GROUP_NAME_int = -1483174486;
	protected static final int HEAP_DUMP_ID_int = -1198575813;
	protected static final int HEAP_DUMP_ID_REF_int = 1586135896;
	protected static final int INVOCATION_CONTEXT_int = -1601973537;
	protected static final int IS_ARRAY_int = 2054496079;
	protected static final int METHOD_ID_int = -443210276;
	protected static final int METHOD_ID_REF_int = -947782377;
	protected static final int NAME_int = 3373707;
	protected static final int NODE_ID_REF_int = 445000854;
	protected static final int NUM_INSTANCES_FIELDS_int = -1583525676;
	protected static final int NUM_INTERFACES_int = 2103939712;
	protected static final int NUM_METHODS_int = -1847438004;
	protected static final int NUM_STATIC_FIELDS_int = -1488120467;
	protected static final int OBJ_ID_int = 105534578;
	protected static final int OBJ_ID_REF_int = 64634561;
	protected static final int OVERHEAD_int = 529694900;
	protected static final int OWNER_OBJ_ID_REF_int = 1741697684;
	protected static final int PARENT_NAME_int = -244870571;
	protected static final int PROCESS_ID_REF_int = 1972566089;
	protected static final int SEQUENCE_COUNTER_int = -360813829;
	protected static final int SIGNATURE_int = 1073584312;
	protected static final int SIG_NOTATION_int = 508763123;
	protected static final int SIZE_int = 3530753;
	protected static final int SOURCE_NAME_int = -1111633594;
	protected static final int STACK_DEPTH_int = 2011131163;
	protected static final int START_LINE_NUM_int = 42438704;
	protected static final int TARGET_OBJECT_ID_REF_int = -1527450766;
	protected static final int THREAD_ID_int = 1473625285;
	protected static final int THREAD_ID_REF_int = 1910215054;
	protected static final int THREAD_NAME_int = -1185159243;
	protected static final int TICKET_int = -873960692;
	protected static final int TIME_int = 3560141;
	protected static final int TRCArrayClassImpl_int = -772116536;
	protected static final int TRCClassImpl_int = -278316113;
	protected static final int TRCFullMethodInvocationImpl_int = -447284631;
	protected static final int TRCFullTraceObjectImpl_int = -116543028;
	protected static final int TRCHeapDumpImpl_int = -475058967;
	protected static final int TRCHeapObjectImpl_int = -506323084;
	protected static final int TRCMethodImpl_int = -450357878;
	protected static final int TRCObjectEntry_int = -541378176;
	protected static final int TRCPackageImpl_int = 779914685;
	protected static final int TRCProcessImpl_int = 73481062;
	protected static final int TRCSourceInfoImpl_int = -90841198;
	protected static final int TRCThreadImpl_int = -912353741;
	protected static final int UNKNOWN_int = -284840886;
	protected static final int VirtualObjectInfo_int = -285893434;
	protected static final int classDef_int = 692408173;
	protected static final int gcFinish_int = -1106218865;
	protected static final int gcStart_int = -161910554;
	protected static final int heapDumpDef_int = 1498850789;
	protected static final int methodDef_int = -854621340;
	protected static final int methodEntry_int = -951145455;
	protected static final int methodExit_int = -723409505;
	protected static final int objAlloc_int = 57510014;
	protected static final int objFree_int = -1660558333;
	protected static final int objReference_int = -1136044012;
	protected static final int runtimeInitDone_int = -557592406;
	protected static final int runtimeShutdown_int = -994909618;
	protected static final int threadEnd_int = -1562259855;
	protected static final int threadStart_int = 1919941752;
	protected static final int traceEnd_int = 1270275414;
	protected static final int traceStart_int = 977069597;
}

==> hyades.source_1.2.2_20040226_1349.zip: org/eclipse/hyades/loaders/trace/TraceConstants.java <==
/**********************************************************************
 * Copyright (c) 2003 Hyades project.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v0.5
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v05.html
 *
 * Contributors:
 * IBM - Initial API and implementation
 **********************************************************************/
package org.eclipse.hyades.loaders.trace;

/**
 * @author slavescu
 */
public class TraceConstants {

	protected static final int ACCESS_int = -1423461020;
	protected static final int AGENT_ID_REF_int = -1203355277;
	protected static final int BASE_TIME_int = -1720547042;
	protected static final int CLASS_CLASS1_int = 1995981828;
	protected static final int CLASS_CLASS2_int = -530663260;
	protected static final int CLASS_ID_int = 853619891;
	protected static final int CLASS_ID_REF_int = -311104800;
	protected static final int CallStackPerThread_int = 688917711;
	protected static final int FIELD_ID_REF_int = 556029086;
	protected static final int GROUP_NAME_int = -1483174486;
	protected static final int HEAP_DUMP_ID_int = -1198575813;
	protected static final int HEAP_DUMP_ID_REF_int = 1586135896;
	protected static final int INVOCATION_CONTEXT_int = -1601973537;
	protected static final int IS_ARRAY_int = 2054496079;
	protected static final int METHOD_ID_int = -443210276;
	protected static final int METHOD_ID_REF_int = -947782377;
	protected static final int NAME_int = 3373707;
	protected static final int NODE_ID_REF_int = 445000854;
	protected static final int NUM_INSTANCES_FIELDS_int = -1583525676;
	protected static final int NUM_INTERFACES_int = 2103939712;
	protected static final int NUM_METHODS_int = -1847438004;
	protected static final int NUM_STATIC_FIELDS_int = -1488120467;
	protected static final int OBJ_ID_int = 105534578;
	protected static final int OBJ_ID_REF_int = 64634561;
	protected static final int OVERHEAD_int = 529694900;
	protected static final int OWNER_OBJ_ID_REF_int = 1741697684;
	protected static final int PARENT_NAME_int = -244870571;
	protected static final int PROCESS_ID_REF_int = 1972566089;
	protected static final int SEQUENCE_COUNTER_int = -360813829;
	protected static final int SIGNATURE_int = 1073584312;
	protected static final int SIG_NOTATION_int = 508763123;
	protected static final int SIZE_int = 3530753;
	protected static final int SOURCE_NAME_int = -1111633594;
	protected static final int STACK_DEPTH_int = 2011131163;
	protected static final int START_LINE_NUM_int = 42438704;
	protected static final int TARGET_OBJECT_ID_REF_int = -1527450766;
	protected static final int THREAD_ID_int = 1473625285;
	protected static final int THREAD_ID_REF_int = 1910215054;
	protected static final int THREAD_NAME_int = -1185159243;
	protected static final int TICKET_int = -873960692;
	protected static final int TIME_int = 3560141;
	protected static final int TRCArrayClassImpl_int = -772116536;
	protected static final int TRCClassImpl_int = -278316113;
	protected static final int TRCFullMethodInvocationImpl_int = -447284631;
	protected static final int TRCFullTraceObjectImpl_int = -116543028;
	protected static final int TRCHeapDumpImpl_int = -475058967;
	protected static final int TRCHeapObjectImpl_int = -506323084;
	protected static final int TRCMethodImpl_int = -450357878;
	protected static final int TRCObjectEntry_int = -541378176;
	protected static final int TRCPackageImpl_int = 779914685;
	protected static final int TRCProcessImpl_int = 73481062;
	protected static final int TRCSourceInfoImpl_int = -90841198;
	protected static final int TRCThreadImpl_int = -912353741;
	protected static final int TYPE_int = 3575610;
	protected static final int UNKNOWN_int = -284840886;
	protected static final int VirtualObjectInfo_int = -285893434;
	protected static final int classDef_int = 692408173;
	protected static final int gcFinish_int = -1106218865;
	protected static final int gcRoot_int = -1252183074;
	protected static final int gcStart_int = -161910554;
	protected static final int heapDumpDef_int = 1498850789;
	protected static final int methodDef_int = -854621340;
	protected static final int methodEntry_int = -951145455;
	protected static final int methodExit_int = -723409505;
	protected static final int objAlloc_int = 57510014;
	protected static final int objFree_int = -1660558333;
	protected static final int objReference_int = -1136044012;
	protected static final int runtimeInitDone_int = -557592406;
	protected static final int runtimeShutdown_int = -994909618;
	protected static final int threadEnd_int = -1562259855;
	protected static final int threadStart_int = 1919941752;
	protected static final int traceEnd_int = 1270275414;
	protected static final int traceStart_int = 977069597;
}
